==> piwigo-2.5.3.zip: piwigo/language/hr_HR/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = 'Nadogradnja';
$lang['Upgrade from version %s to %s'] = 'Nadogradnja sa inačice %s na %s';
$lang['Statistics'] = 'Statistika';
$lang['total upgrade time'] = 'sveukupno vrijeme nadogradnje';
$lang['total SQL time'] = 'sveukupno SQL vrijeme';
$lang['SQL queries'] = 'SQL upita';
$lang['Upgrade informations'] = 'Podaci o nadogradnji';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Izvršite radnu provjeru [Uprava>Alati>Održavanje] u slučaju bilo kakvih problema.';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Samo upravnik može pokrenuti nadogradnju: molimo, prijavite se dolje.';
$lang['You do not have access rights to run upgrade'] = 'Nemate pristupna prava za pokretanje nadogradnje';
$lang['All sub-albums of private albums become private'] = 'Sve podskupine osobnih skupina postaju osobne';
$lang['User permissions and group permissions have been erased'] = 'Korisničke i grupne dozvole su izbrisane';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Jedino su predznaci poveznih sličica i webmaster-ova e-mail adresa sačuvane iz prethodne postave';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Na ovoj stranici imate prijedlog nadogradnje baze podataka sa vaše starije inačice na novu. Pomoćnik nadogradnje smatra da trenutno koristite <strong>inačicu %s</strong> (ili sličnu).';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Kao mjera predostrožnosti, slijedeći dodaci su isključeni. Provjerite dostupne nadogradnje dodataka prije njihovog ponovnog uključenja:';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'U <i>%s</i>, prije <b>?></b>, ubaci:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Sljedeće teme su preventivno deaktivirane. Prije ponovnog aktiviranja morate provjeriti postoje li nadogradnje:';

?>

==> piwigo-16.1.0.zip: piwigo/language/hr_HR/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = 'Nadogradnja';
$lang['Upgrade from version %s to %s'] = 'Nadogradnja sa inačice %s na %s';
$lang['Statistics'] = 'Statistika';
$lang['total upgrade time'] = 'sveukupno vrijeme nadogradnje';
$lang['total SQL time'] = 'sveukupno SQL vrijeme';
$lang['SQL queries'] = 'SQL upita';
$lang['Upgrade informations'] = 'Podaci o nadogradnji';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Izvršite radnu provjeru [Uprava>Alati>Održavanje] u slučaju bilo kakvih problema.';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Samo upravnik može pokrenuti nadogradnju: molimo, prijavite se dolje.';
$lang['You do not have access rights to run upgrade'] = 'Nemate pristupna prava za pokretanje nadogradnje';
$lang['All sub-albums of private albums become private'] = 'Sve podskupine osobnih skupina postaju osobne';
$lang['User permissions and group permissions have been erased'] = 'Korisničke i grupne dozvole su izbrisane';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Jedino su predznaci poveznih sličica i webmaster-ova e-mail adresa sačuvane iz prethodne postave';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Na ovoj stranici imate prijedlog nadogradnje baze podataka sa vaše starije inačice na novu. Pomoćnik nadogradnje smatra da trenutno koristite <strong>inačicu %s</strong> (ili sličnu).';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Kao mjera predostrožnosti, slijedeći dodaci su isključeni. Provjerite dostupne nadogradnje dodataka prije njihovog ponovnog uključenja:';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'U <i>%s</i>, prije <b>?></b>, ubaci:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Sljedeće teme su preventivno deaktivirane. Prije ponovnog aktiviranja morate provjeriti postoje li nadogradnje:';

?>
